package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TAttach;
import com.ruoyi.system.application.service.ITAttachService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 附件Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/attach")
public class TAttachController extends BaseController
{
    @Autowired
    private ITAttachService tAttachService;

    /**
     * 查询附件列表
     */
    @RequiresPermissions("application:attach:list")
    @GetMapping("/list")
    public TableDataInfo list(TAttach tAttach)
    {
        startPage();
        List<TAttach> list = tAttachService.selectTAttachList(tAttach);
        return getDataTable(list);
    }

    /**
     * 导出附件列表
     */
    @RequiresPermissions("application:attach:export")
    @Log(title = "附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TAttach tAttach)
    {
        List<TAttach> list = tAttachService.selectTAttachList(tAttach);
        ExcelUtil<TAttach> util = new ExcelUtil<TAttach>(TAttach.class);
        util.exportExcel(response, list, "附件数据");
    }
    /**
     * 获取附件详细信息
     */
    @RequiresPermissions("application:attach:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tAttachService.selectTAttachById(id));
    }

    /**
     * 新增附件
     */
    @RequiresPermissions("application:attach:add")
    @Log(title = "附件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TAttach tAttach)
    {
        return toAjax(tAttachService.insertTAttach(tAttach));
    }

    /**
     * 修改附件
     */
    @RequiresPermissions("application:attach:edit")
    @Log(title = "附件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TAttach tAttach)
    {
        return toAjax(tAttachService.updateTAttach(tAttach));
    }

    /**
     * 删除附件
     */
    @RequiresPermissions("application:attach:remove")
    @Log(title = "附件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tAttachService.deleteTAttachByIds(ids));
    }
}
