package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUAccount;
import com.ruoyi.system.application.service.ITUAccountService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 账户Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/account")
public class TUAccountController extends BaseController
{
    @Autowired
    private ITUAccountService tUAccountService;

    /**
     * 查询账户列表
     */
    @RequiresPermissions("application:account:list")
    @GetMapping("/list")
    public TableDataInfo list(TUAccount tUAccount)
    {
        startPage();
        List<TUAccount> list = tUAccountService.selectTUAccountList(tUAccount);
        return getDataTable(list);
    }

    /**
     * 导出账户列表
     */
    @RequiresPermissions("application:account:export")
    @Log(title = "账户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUAccount tUAccount)
    {
        List<TUAccount> list = tUAccountService.selectTUAccountList(tUAccount);
        ExcelUtil<TUAccount> util = new ExcelUtil<TUAccount>(TUAccount.class);
        util.exportExcel(response, list, "账户数据");
    }

    /**
     * 获取账户详细信息
     */
    @RequiresPermissions("application:account:query")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(tUAccountService.selectTUAccountByUserId(userId));
    }

    /**
     * 新增账户
     */
    @RequiresPermissions("application:account:add")
    @Log(title = "账户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUAccount tUAccount)
    {
        return toAjax(tUAccountService.insertTUAccount(tUAccount));
    }

    /**
     * 修改账户
     */
    @RequiresPermissions("application:account:edit")
    @Log(title = "账户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUAccount tUAccount)
    {
        return toAjax(tUAccountService.updateTUAccount(tUAccount));
    }

    /**
     * 删除账户
     */
    @RequiresPermissions("application:account:remove")
    @Log(title = "账户", businessType = BusinessType.DELETE)
	@DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        return toAjax(tUAccountService.deleteTUAccountByUserIds(userIds));
    }
}
