package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUAccountLog;
import com.ruoyi.system.application.service.ITUAccountLogService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 账户日志Controller
 * 
 * @author ruoyi
 * @date 2024-06-19
 */
@RestController
@RequestMapping("/application/accountlog")
public class TUAccountLogController extends BaseController
{
    @Autowired
    private ITUAccountLogService tUAccountLogService;

    /**
     * 查询账户日志列表
     */
    @RequiresPermissions("application:accountlog:list")
    @GetMapping("/list")
    public TableDataInfo list(TUAccountLog tUAccountLog)
    {
        startPage();
        List<TUAccountLog> list = tUAccountLogService.selectTUAccountLogList(tUAccountLog);
        return getDataTable(list);
    }

    /**
     * 导出账户日志列表
     */
    @RequiresPermissions("application:accountlog:export")
    @Log(title = "账户日志", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUAccountLog tUAccountLog)
    {
        List<TUAccountLog> list = tUAccountLogService.selectTUAccountLogList(tUAccountLog);
        ExcelUtil<TUAccountLog> util = new ExcelUtil<TUAccountLog>(TUAccountLog.class);
        util.exportExcel(response, list, "账户日志数据");
    }

    /**
     * 获取账户日志详细信息
     */
    @RequiresPermissions("application:accountlog:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUAccountLogService.selectTUAccountLogById(id));
    }

    /**
     * 新增账户日志
     */
    @RequiresPermissions("application:accountlog:add")
    @Log(title = "账户日志", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUAccountLog tUAccountLog)
    {
        return toAjax(tUAccountLogService.insertTUAccountLog(tUAccountLog));
    }

    /**
     * 修改账户日志
     */
    @RequiresPermissions("application:accountlog:edit")
    @Log(title = "账户日志", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUAccountLog tUAccountLog)
    {
        return toAjax(tUAccountLogService.updateTUAccountLog(tUAccountLog));
    }

    /**
     * 删除账户日志
     */
    @RequiresPermissions("application:accountlog:remove")
    @Log(title = "账户日志", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUAccountLogService.deleteTUAccountLogByIds(ids));
    }
}
