package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUBanner;
import com.ruoyi.system.application.service.ITUBannerService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 首页bannerController
 * 
 * @author ruoyi
 * @date 2024-06-03
 */
@RestController
@RequestMapping("/application/banner")
public class TUBannerController extends BaseController
{
    @Autowired
    private ITUBannerService tUBannerService;

    /**
     * 查询首页banner列表
     */
    @RequiresPermissions("application:banner:list")
    @GetMapping("/list")
    public TableDataInfo list(TUBanner tUBanner)
    {
        startPage();
        List<TUBanner> list = tUBannerService.selectTUBannerList(tUBanner);
        return getDataTable(list);
    }

    /**
     * 导出首页banner列表
     */
    @RequiresPermissions("application:banner:export")
    @Log(title = "首页banner", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUBanner tUBanner)
    {
        List<TUBanner> list = tUBannerService.selectTUBannerList(tUBanner);
        ExcelUtil<TUBanner> util = new ExcelUtil<TUBanner>(TUBanner.class);
        util.exportExcel(response, list, "首页banner数据");
    }

    /**
     * 获取首页banner详细信息
     */
    @RequiresPermissions("application:banner:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUBannerService.selectTUBannerById(id));
    }

    /**
     * 新增首页banner
     */
    @RequiresPermissions("application:banner:add")
    @Log(title = "首页banner", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUBanner tUBanner)
    {
        return toAjax(tUBannerService.insertTUBanner(tUBanner));
    }

    /**
     * 修改首页banner
     */
    @RequiresPermissions("application:banner:edit")
    @Log(title = "首页banner", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUBanner tUBanner)
    {
        return toAjax(tUBannerService.updateTUBanner(tUBanner));
    }

    /**
     * 删除首页banner
     */
    @RequiresPermissions("application:banner:remove")
    @Log(title = "首页banner", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUBannerService.deleteTUBannerByIds(ids));
    }
}
