package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUCustomerser;
import com.ruoyi.system.application.service.ITUCustomerserService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 客服信息Controller
 * 
 * @author ruoyi
 * @date 2024-07-02
 */
@RestController
@RequestMapping("/application/customerser")
public class TUCustomerserController extends BaseController
{
    @Autowired
    private ITUCustomerserService tUCustomerserService;

    /**
     * 查询客服信息列表
     */
    @RequiresPermissions("application:customerser:list")
    @GetMapping("/list")
    public TableDataInfo list(TUCustomerser tUCustomerser)
    {
        startPage();
        List<TUCustomerser> list = tUCustomerserService.selectTUCustomerserList(tUCustomerser);
        return getDataTable(list);
    }

    /**
     * 导出客服信息列表
     */
    @RequiresPermissions("application:customerser:export")
    @Log(title = "客服信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUCustomerser tUCustomerser)
    {
        List<TUCustomerser> list = tUCustomerserService.selectTUCustomerserList(tUCustomerser);
        ExcelUtil<TUCustomerser> util = new ExcelUtil<TUCustomerser>(TUCustomerser.class);
        util.exportExcel(response, list, "客服信息数据");
    }

    /**
     * 获取客服信息详细信息
     */
    @RequiresPermissions("application:customerser:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUCustomerserService.selectTUCustomerserById(id));
    }

    /**
     * 新增客服信息
     */
    @RequiresPermissions("application:customerser:add")
    @Log(title = "客服信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUCustomerser tUCustomerser)
    {
        return toAjax(tUCustomerserService.insertTUCustomerser(tUCustomerser));
    }

    /**
     * 修改客服信息
     */
    @RequiresPermissions("application:customerser:edit")
    @Log(title = "客服信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUCustomerser tUCustomerser)
    {
        return toAjax(tUCustomerserService.updateTUCustomerser(tUCustomerser));
    }

    /**
     * 删除客服信息
     */
    @RequiresPermissions("application:customerser:remove")
    @Log(title = "客服信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUCustomerserService.deleteTUCustomerserByIds(ids));
    }
}
