package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUEvaluate;
import com.ruoyi.system.application.service.ITUEvaluateService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 评价Controller
 * 
 * @author ruoyi
 * @date 2024-07-03
 */
@RestController
@RequestMapping("/application/evaluate")
public class TUEvaluateController extends BaseController
{
    @Autowired
    private ITUEvaluateService tUEvaluateService;

    /**
     * 查询评价列表
     */
    @RequiresPermissions("application:evaluate:list")
    @GetMapping("/list")
    public TableDataInfo list(TUEvaluate tUEvaluate)
    {
        startPage();
        List<TUEvaluate> list = tUEvaluateService.selectTUEvaluateList(tUEvaluate);
        return getDataTable(list);
    }

    /**
     * 导出评价列表
     */
    @RequiresPermissions("application:evaluate:export")
    @Log(title = "评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUEvaluate tUEvaluate)
    {
        List<TUEvaluate> list = tUEvaluateService.selectTUEvaluateList(tUEvaluate);
        ExcelUtil<TUEvaluate> util = new ExcelUtil<TUEvaluate>(TUEvaluate.class);
        util.exportExcel(response, list, "评价数据");
    }

    /**
     * 获取评价详细信息
     */
    @RequiresPermissions("application:evaluate:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUEvaluateService.selectTUEvaluateById(id));
    }

    /**
     * 新增评价
     */
    @RequiresPermissions("application:evaluate:add")
    @Log(title = "评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUEvaluate tUEvaluate)
    {
        return toAjax(tUEvaluateService.insertTUEvaluate(tUEvaluate));
    }

    /**
     * 修改评价
     */
    @RequiresPermissions("application:evaluate:edit")
    @Log(title = "评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUEvaluate tUEvaluate)
    {
        return toAjax(tUEvaluateService.updateTUEvaluate(tUEvaluate));
    }

    /**
     * 删除评价
     */
    @RequiresPermissions("application:evaluate:remove")
    @Log(title = "评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUEvaluateService.deleteTUEvaluateByIds(ids));
    }
}
