package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUGradesubject;
import com.ruoyi.system.application.service.ITUGradesubjectService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 年级学科对应Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/gradesubject")
public class TUGradesubjectController extends BaseController
{
    @Autowired
    private ITUGradesubjectService tUGradesubjectService;

    /**
     * 查询年级学科对应列表
     */
    @RequiresPermissions("application:gradesubject:list")
    @GetMapping("/list")
    public TableDataInfo list(TUGradesubject tUGradesubject)
    {
        startPage();
        List<TUGradesubject> list = tUGradesubjectService.selectTUGradesubjectList(tUGradesubject);
        return getDataTable(list);
    }

    /**
     * 导出年级学科对应列表
     */
    @RequiresPermissions("application:gradesubject:export")
    @Log(title = "年级学科对应", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUGradesubject tUGradesubject)
    {
        List<TUGradesubject> list = tUGradesubjectService.selectTUGradesubjectList(tUGradesubject);
        ExcelUtil<TUGradesubject> util = new ExcelUtil<TUGradesubject>(TUGradesubject.class);
        util.exportExcel(response, list, "年级学科对应数据");
    }

    /**
     * 获取年级学科对应详细信息
     */
    @RequiresPermissions("application:gradesubject:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUGradesubjectService.selectTUGradesubjectById(id));
    }

    /**
     * 新增年级学科对应
     */
    @RequiresPermissions("application:gradesubject:add")
    @Log(title = "年级学科对应", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUGradesubject tUGradesubject)
    {
        return toAjax(tUGradesubjectService.insertTUGradesubject(tUGradesubject));
    }

    /**
     * 修改年级学科对应
     */
    @RequiresPermissions("application:gradesubject:edit")
    @Log(title = "年级学科对应", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUGradesubject tUGradesubject)
    {
        return toAjax(tUGradesubjectService.updateTUGradesubject(tUGradesubject));
    }

    /**
     * 删除年级学科对应
     */
    @RequiresPermissions("application:gradesubject:remove")
    @Log(title = "年级学科对应", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUGradesubjectService.deleteTUGradesubjectByIds(ids));
    }
}
