package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TULookcollection;
import com.ruoyi.system.application.service.ITULookcollectionService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 看过和收藏Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/lookcollection")
public class TULookcollectionController extends BaseController
{
    @Autowired
    private ITULookcollectionService tULookcollectionService;

    /**
     * 查询看过和收藏列表
     */
    @RequiresPermissions("application:lookcollection:list")
    @GetMapping("/list")
    public TableDataInfo list(TULookcollection tULookcollection)
    {
        startPage();
        List<TULookcollection> list = tULookcollectionService.selectTULookcollectionList(tULookcollection);
        return getDataTable(list);
    }

    /**
     * 导出看过和收藏列表
     */
    @RequiresPermissions("application:lookcollection:export")
    @Log(title = "看过和收藏", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TULookcollection tULookcollection)
    {
        List<TULookcollection> list = tULookcollectionService.selectTULookcollectionList(tULookcollection);
        ExcelUtil<TULookcollection> util = new ExcelUtil<TULookcollection>(TULookcollection.class);
        util.exportExcel(response, list, "看过和收藏数据");
    }

    /**
     * 获取看过和收藏详细信息
     */
    @RequiresPermissions("application:lookcollection:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tULookcollectionService.selectTULookcollectionById(id));
    }

    /**
     * 新增看过和收藏
     */
    @RequiresPermissions("application:lookcollection:add")
    @Log(title = "看过和收藏", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TULookcollection tULookcollection)
    {
        return toAjax(tULookcollectionService.insertTULookcollection(tULookcollection));
    }

    /**
     * 修改看过和收藏
     */
    @RequiresPermissions("application:lookcollection:edit")
    @Log(title = "看过和收藏", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TULookcollection tULookcollection)
    {
        return toAjax(tULookcollectionService.updateTULookcollection(tULookcollection));
    }

    /**
     * 删除看过和收藏
     */
    @RequiresPermissions("application:lookcollection:remove")
    @Log(title = "看过和收藏", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tULookcollectionService.deleteTULookcollectionByIds(ids));
    }
}
