package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TULookorder;
import com.ruoyi.system.application.service.ITULookorderService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 看过的订单Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/lookorder")
public class TULookorderController extends BaseController
{
    @Autowired
    private ITULookorderService tULookorderService;

    /**
     * 查询看过的订单列表
     */
    @RequiresPermissions("application:lookorder:list")
    @GetMapping("/list")
    public TableDataInfo list(TULookorder tULookorder)
    {
        startPage();
        List<TULookorder> list = tULookorderService.selectTULookorderList(tULookorder);
        return getDataTable(list);
    }

    /**
     * 导出看过的订单列表
     */
    @RequiresPermissions("application:lookorder:export")
    @Log(title = "看过的订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TULookorder tULookorder)
    {
        List<TULookorder> list = tULookorderService.selectTULookorderList(tULookorder);
        ExcelUtil<TULookorder> util = new ExcelUtil<TULookorder>(TULookorder.class);
        util.exportExcel(response, list, "看过的订单数据");
    }

    /**
     * 获取看过的订单详细信息
     */
    @RequiresPermissions("application:lookorder:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tULookorderService.selectTULookorderById(id));
    }

    /**
     * 新增看过的订单
     */
    @RequiresPermissions("application:lookorder:add")
    @Log(title = "看过的订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TULookorder tULookorder)
    {
        return toAjax(tULookorderService.insertTULookorder(tULookorder));
    }

    /**
     * 修改看过的订单
     */
    @RequiresPermissions("application:lookorder:edit")
    @Log(title = "看过的订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TULookorder tULookorder)
    {
        return toAjax(tULookorderService.updateTULookorder(tULookorder));
    }

    /**
     * 删除看过的订单
     */
    @RequiresPermissions("application:lookorder:remove")
    @Log(title = "看过的订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tULookorderService.deleteTULookorderByIds(ids));
    }
}
