package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUOrder;
import com.ruoyi.system.application.service.ITUOrderService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 业务订单Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/order")
public class TUOrderController extends BaseController
{
    @Autowired
    private ITUOrderService tUOrderService;

    /**
     * 查询业务订单列表
     */
    @RequiresPermissions("application:order:list")
    @GetMapping("/list")
    public TableDataInfo list(TUOrder tUOrder)
    {
        startPage();
        List<TUOrder> list = tUOrderService.selectTUOrderList(tUOrder);
        return getDataTable(list);
    }

    /**
     * 导出业务订单列表
     */
    @RequiresPermissions("application:order:export")
    @Log(title = "业务订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUOrder tUOrder)
    {
        List<TUOrder> list = tUOrderService.selectTUOrderList(tUOrder);
        ExcelUtil<TUOrder> util = new ExcelUtil<TUOrder>(TUOrder.class);
        util.exportExcel(response, list, "业务订单数据");
    }

    /**
     * 获取业务订单详细信息
     */
    @RequiresPermissions("application:order:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUOrderService.selectTUOrderById(id));
    }

    /**
     * 新增业务订单
     */
    @RequiresPermissions("application:order:add")
    @Log(title = "业务订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUOrder tUOrder)
    {
        return toAjax(tUOrderService.insertTUOrder(tUOrder));
    }

    /**
     * 修改业务订单
     */
    @RequiresPermissions("application:order:edit")
    @Log(title = "业务订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUOrder tUOrder)
    {
        return toAjax(tUOrderService.updateTUOrder(tUOrder));
    }

    /**
     * 删除业务订单
     */
    @RequiresPermissions("application:order:remove")
    @Log(title = "业务订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUOrderService.deleteTUOrderByIds(ids));
    }
}
