package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.application.domain.TUSchool;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.service.ITUSchoolService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 学校信息Controller
 * 
 * @author ruoyi
 * @date 2024-06-27
 */
@RestController
@RequestMapping("/application/school")
public class TUSchoolController extends BaseController
{
    @Autowired
    private ITUSchoolService tUSchoolService;

    /**
     * 查询学校信息列表
     */
    @RequiresPermissions("application:school:list")
    @GetMapping("/list")
    public TableDataInfo list(TUSchool tUSchool)
    {
        startPage();
        List<TUSchool> list = tUSchoolService.selectTUSchoolList(tUSchool);
        return getDataTable(list);
    }


    /**
     * 导出学校信息列表
     */
    @RequiresPermissions("application:school:export")
    @Log(title = "学校信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUSchool tUSchool)
    {
        List<TUSchool> list = tUSchoolService.selectTUSchoolList(tUSchool);
        ExcelUtil<TUSchool> util = new ExcelUtil<TUSchool>(TUSchool.class);
        util.exportExcel(response, list, "学校信息数据");
    }

    /**
     * 获取学校信息详细信息
     */
    @RequiresPermissions("application:school:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUSchoolService.selectTUSchoolById(id));
    }

    /**
     * 新增学校信息
     */
    @RequiresPermissions("application:school:add")
    @Log(title = "学校信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUSchool tUSchool)
    {
        return toAjax(tUSchoolService.insertTUSchool(tUSchool));
    }

    /**
     * 修改学校信息
     */
    @RequiresPermissions("application:school:edit")
    @Log(title = "学校信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUSchool tUSchool)
    {
        return toAjax(tUSchoolService.updateTUSchool(tUSchool));
    }

    /**
     * 删除学校信息
     */
    @RequiresPermissions("application:school:remove")
    @Log(title = "学校信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUSchoolService.deleteTUSchoolByIds(ids));
    }
}
