package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUTeacherArea;
import com.ruoyi.system.application.service.ITUTeacherAreaService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 教师对应区域Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/area")
public class TUTeacherAreaController extends BaseController
{
    @Autowired
    private ITUTeacherAreaService tUTeacherAreaService;

    /**
     * 查询教师对应区域列表
     */
    @RequiresPermissions("application:area:list")
    @GetMapping("/list")
    public TableDataInfo list(TUTeacherArea tUTeacherArea)
    {
        startPage();
        List<TUTeacherArea> list = tUTeacherAreaService.selectTUTeacherAreaList(tUTeacherArea);
        return getDataTable(list);
    }

    /**
     * 导出教师对应区域列表
     */
    @RequiresPermissions("application:area:export")
    @Log(title = "教师对应区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUTeacherArea tUTeacherArea)
    {
        List<TUTeacherArea> list = tUTeacherAreaService.selectTUTeacherAreaList(tUTeacherArea);
        ExcelUtil<TUTeacherArea> util = new ExcelUtil<TUTeacherArea>(TUTeacherArea.class);
        util.exportExcel(response, list, "教师对应区域数据");
    }

    /**
     * 获取教师对应区域详细信息
     */
    @RequiresPermissions("application:area:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUTeacherAreaService.selectTUTeacherAreaById(id));
    }

    /**
     * 新增教师对应区域
     */
    @RequiresPermissions("application:area:add")
    @Log(title = "教师对应区域", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUTeacherArea tUTeacherArea)
    {
        return toAjax(tUTeacherAreaService.insertTUTeacherArea(tUTeacherArea));
    }

    /**
     * 修改教师对应区域
     */
    @RequiresPermissions("application:area:edit")
    @Log(title = "教师对应区域", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUTeacherArea tUTeacherArea)
    {
        return toAjax(tUTeacherAreaService.updateTUTeacherArea(tUTeacherArea));
    }

    /**
     * 删除教师对应区域
     */
    @RequiresPermissions("application:area:remove")
    @Log(title = "教师对应区域", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUTeacherAreaService.deleteTUTeacherAreaByIds(ids));
    }
}
