package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUTeacher;
import com.ruoyi.system.application.service.ITUTeacherService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 教师基本信息Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/teacher")
public class TUTeacherController extends BaseController
{
    @Autowired
    private ITUTeacherService tUTeacherService;

    /**
     * 查询教师基本信息列表
     */
    @RequiresPermissions("application:teacher:list")
    @GetMapping("/list")
    public TableDataInfo list(TUTeacher tUTeacher)
    {
        startPage();
        List<TUTeacher> list = tUTeacherService.selectTUTeacherList(tUTeacher);
        return getDataTable(list);
    }

    /**
     * 导出教师基本信息列表
     */
    @RequiresPermissions("application:teacher:export")
    @Log(title = "教师基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUTeacher tUTeacher)
    {
        List<TUTeacher> list = tUTeacherService.selectTUTeacherList(tUTeacher);
        ExcelUtil<TUTeacher> util = new ExcelUtil<TUTeacher>(TUTeacher.class);
        util.exportExcel(response, list, "教师基本信息数据");
    }

    /**
     * 获取教师基本信息详细信息
     */
    @RequiresPermissions("application:teacher:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUTeacherService.selectTUTeacherById(id));
    }

    /**
     * 新增教师基本信息
     */
    @RequiresPermissions("application:teacher:add")
    @Log(title = "教师基本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUTeacher tUTeacher)
    {
        return toAjax(tUTeacherService.insertTUTeacher(tUTeacher));
    }

    /**
     * 修改教师基本信息
     */
    @RequiresPermissions("application:teacher:edit")
    @Log(title = "教师基本信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUTeacher tUTeacher)
    {
        return toAjax(tUTeacherService.updateTUTeacher(tUTeacher));
    }

    /**
     * 删除教师基本信息
     */
    @RequiresPermissions("application:teacher:remove")
    @Log(title = "教师基本信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUTeacherService.deleteTUTeacherByIds(ids));
    }
}
