package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUTeacherGradesubject;
import com.ruoyi.system.application.service.ITUTeacherGradesubjectService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 教师对应学科Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/teacher_gradesubject")
public class TUTeacherGradesubjectController extends BaseController
{
    @Autowired
    private ITUTeacherGradesubjectService tUTeacherGradesubjectService;

    /**
     * 查询教师对应学科列表
     */
    @RequiresPermissions("application:teacher_gradesubject:list")
    @GetMapping("/list")
    public TableDataInfo list(TUTeacherGradesubject tUTeacherGradesubject)
    {
        startPage();
        List<TUTeacherGradesubject> list = tUTeacherGradesubjectService.selectTUTeacherGradesubjectList(tUTeacherGradesubject);
        return getDataTable(list);
    }

    /**
     * 导出教师对应学科列表
     */
    @RequiresPermissions("application:teacher_gradesubject:export")
    @Log(title = "教师对应学科", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUTeacherGradesubject tUTeacherGradesubject)
    {
        List<TUTeacherGradesubject> list = tUTeacherGradesubjectService.selectTUTeacherGradesubjectList(tUTeacherGradesubject);
        ExcelUtil<TUTeacherGradesubject> util = new ExcelUtil<TUTeacherGradesubject>(TUTeacherGradesubject.class);
        util.exportExcel(response, list, "教师对应学科数据");
    }

    /**
     * 获取教师对应学科详细信息
     */
    @RequiresPermissions("application:teacher_gradesubject:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUTeacherGradesubjectService.selectTUTeacherGradesubjectById(id));
    }

    /**
     * 新增教师对应学科
     */
    @RequiresPermissions("application:teacher_gradesubject:add")
    @Log(title = "教师对应学科", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUTeacherGradesubject tUTeacherGradesubject)
    {
        return toAjax(tUTeacherGradesubjectService.insertTUTeacherGradesubject(tUTeacherGradesubject));
    }

    /**
     * 修改教师对应学科
     */
    @RequiresPermissions("application:teacher_gradesubject:edit")
    @Log(title = "教师对应学科", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUTeacherGradesubject tUTeacherGradesubject)
    {
        return toAjax(tUTeacherGradesubjectService.updateTUTeacherGradesubject(tUTeacherGradesubject));
    }

    /**
     * 删除教师对应学科
     */
    @RequiresPermissions("application:teacher_gradesubject:remove")
    @Log(title = "教师对应学科", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUTeacherGradesubjectService.deleteTUTeacherGradesubjectByIds(ids));
    }
}
