package com.ruoyi.system.application.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.application.domain.TUTeachingarea;
import com.ruoyi.system.application.service.ITUTeachingareaService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 教学区域Controller
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@RestController
@RequestMapping("/application/teachingarea")
public class TUTeachingareaController extends BaseController
{
    @Autowired
    private ITUTeachingareaService tUTeachingareaService;

    /**
     * 查询教学区域列表
     */
    @RequiresPermissions("application:teachingarea:list")
    @GetMapping("/list")
    public TableDataInfo list(TUTeachingarea tUTeachingarea)
    {
        startPage();
        List<TUTeachingarea> list = tUTeachingareaService.selectTUTeachingareaList(tUTeachingarea);
        return getDataTable(list);
    }

    /**
     * 导出教学区域列表
     */
    @RequiresPermissions("application:teachingarea:export")
    @Log(title = "教学区域", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TUTeachingarea tUTeachingarea)
    {
        List<TUTeachingarea> list = tUTeachingareaService.selectTUTeachingareaList(tUTeachingarea);
        ExcelUtil<TUTeachingarea> util = new ExcelUtil<TUTeachingarea>(TUTeachingarea.class);
        util.exportExcel(response, list, "教学区域数据");
    }

    /**
     * 获取教学区域详细信息
     */
    @RequiresPermissions("application:teachingarea:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(tUTeachingareaService.selectTUTeachingareaById(id));
    }

    /**
     * 新增教学区域
     */
    @RequiresPermissions("application:teachingarea:add")
    @Log(title = "教学区域", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUTeachingarea tUTeachingarea)
    {
        return toAjax(tUTeachingareaService.insertTUTeachingarea(tUTeachingarea));
    }

    /**
     * 修改教学区域
     */
    @RequiresPermissions("application:teachingarea:edit")
    @Log(title = "教学区域", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUTeachingarea tUTeachingarea)
    {
        return toAjax(tUTeachingareaService.updateTUTeachingarea(tUTeachingarea));
    }

    /**
     * 删除教学区域
     */
    @RequiresPermissions("application:teachingarea:remove")
    @Log(title = "教学区域", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(tUTeachingareaService.deleteTUTeachingareaByIds(ids));
    }
}
