package com.ruoyi.system.application.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.application.mapper.TUAccountMapper;
import com.ruoyi.system.application.domain.TUAccount;
import com.ruoyi.system.application.service.ITUAccountService;

/**
 * 账户Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@Service
public class TUAccountServiceImpl implements ITUAccountService 
{
    @Autowired
    private TUAccountMapper tUAccountMapper;

    /**
     * 查询账户
     * 
     * @param userId 账户主键
     * @return 账户
     */
    @Override
    public TUAccount selectTUAccountByUserId(Long userId)
    {
        return tUAccountMapper.selectTUAccountByUserId(userId);
    }

    /**
     * 查询账户列表
     * 
     * @param tUAccount 账户
     * @return 账户
     */
    @Override
    public List<TUAccount> selectTUAccountList(TUAccount tUAccount)
    {
        return tUAccountMapper.selectTUAccountList(tUAccount);
    }

    /**
     * 新增账户
     * 
     * @param tUAccount 账户
     * @return 结果
     */
    @Override
    public int insertTUAccount(TUAccount tUAccount)
    {
        return tUAccountMapper.insertTUAccount(tUAccount);
    }

    /**
     * 修改账户
     * 
     * @param tUAccount 账户
     * @return 结果
     */
    @Override
    public int updateTUAccount(TUAccount tUAccount)
    {
        tUAccount.setUpdateTime(DateUtils.getNowDate());
        return tUAccountMapper.updateTUAccount(tUAccount);
    }

    /**
     * 批量删除账户
     * 
     * @param userIds 需要删除的账户主键
     * @return 结果
     */
    @Override
    public int deleteTUAccountByUserIds(Long[] userIds)
    {
        return tUAccountMapper.deleteTUAccountByUserIds(userIds);
    }

    /**
     * 删除账户信息
     * 
     * @param userId 账户主键
     * @return 结果
     */
    @Override
    public int deleteTUAccountByUserId(Long userId)
    {
        return tUAccountMapper.deleteTUAccountByUserId(userId);
    }
}
