package com.ruoyi.system.application.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.application.mapper.TULookorderMapper;
import com.ruoyi.system.application.domain.TULookorder;
import com.ruoyi.system.application.service.ITULookorderService;

/**
 * 看过的订单Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-06-01
 */
@Service
public class TULookorderServiceImpl implements ITULookorderService 
{
    @Autowired
    private TULookorderMapper tULookorderMapper;

    /**
     * 查询看过的订单
     * 
     * @param id 看过的订单主键
     * @return 看过的订单
     */
    @Override
    public TULookorder selectTULookorderById(String id)
    {
        return tULookorderMapper.selectTULookorderById(id);
    }

    /**
     * 查询看过的订单列表
     * 
     * @param tULookorder 看过的订单
     * @return 看过的订单
     */
    @Override
    public List<TULookorder> selectTULookorderList(TULookorder tULookorder)
    {
        return tULookorderMapper.selectTULookorderList(tULookorder);
    }

    /**
     * 新增看过的订单
     * 
     * @param tULookorder 看过的订单
     * @return 结果
     */
    @Override
    public int insertTULookorder(TULookorder tULookorder)
    {
        return tULookorderMapper.insertTULookorder(tULookorder);
    }

    /**
     * 修改看过的订单
     * 
     * @param tULookorder 看过的订单
     * @return 结果
     */
    @Override
    public int updateTULookorder(TULookorder tULookorder)
    {
        tULookorder.setUpdateTime(DateUtils.getNowDate());
        return tULookorderMapper.updateTULookorder(tULookorder);
    }

    /**
     * 批量删除看过的订单
     * 
     * @param ids 需要删除的看过的订单主键
     * @return 结果
     */
    @Override
    public int deleteTULookorderByIds(String[] ids)
    {
        return tULookorderMapper.deleteTULookorderByIds(ids);
    }

    /**
     * 删除看过的订单信息
     * 
     * @param id 看过的订单主键
     * @return 结果
     */
    @Override
    public int deleteTULookorderById(String id)
    {
        return tULookorderMapper.deleteTULookorderById(id);
    }
}
