package com.ruoyi.system.payment.component;

import com.github.binarywang.wxpay.bean.order.WxPayMpOrderResult;
import com.github.binarywang.wxpay.bean.request.BaseWxPayRequest;
import com.github.binarywang.wxpay.bean.request.WxPayRefundRequest;
import com.github.binarywang.wxpay.bean.request.WxPayUnifiedOrderRequest;
import com.github.binarywang.wxpay.bean.result.WxPayRefundResult;
import com.github.binarywang.wxpay.config.WxPayConfig;
import com.github.binarywang.wxpay.exception.WxPayException;
import com.github.binarywang.wxpay.service.WxPayService;
import com.github.binarywang.wxpay.service.impl.WxPayServiceImpl;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.system.payment.domain.PayConfig;
import com.ruoyi.system.payment.service.IPayConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;

import java.net.InetAddress;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * @Author：魏建波 Date：2024/3/11
 * <p>
 * Time：10:08
 */
@Component
public class WeChatPayComponent {
    @Autowired
    IPayConfigService payConfigService;
    PayConfig myPayConfig;
    @Autowired
    WxPayService wxPayService;
    @Bean
    public WxPayService getWxPayService(){
        // 获得数据库中支付配置
        myPayConfig = payConfigService.selectPayConfigByPayConfigId(1L);
        // 创建微信支付的配置对象
        WxPayConfig payConfig = new WxPayConfig();
        payConfig.setAppId(myPayConfig.getAppId());
        payConfig.setMchId(myPayConfig.getMchId());
        payConfig.setMchKey(myPayConfig.getMchKey());
        /*服务商模式*/
//            payConfig.setSubAppId(StringUtils.trimToNull(this.properties.getSubAppId()));
//            payConfig.setSubMchId(StringUtils.trimToNull(this.properties.getSubMchId()));
        payConfig.setKeyPath(myPayConfig.getKeyPath());
        // 可以指定是否使用沙箱环境
        payConfig.setUseSandboxEnv(false);
        WxPayService wxPayService = new WxPayServiceImpl();
        wxPayService.setConfig(payConfig);
        return wxPayService;
    }
    /**
     * 微信支付
     * @param amount 单位元
     * @param openid 微信标识
     * @return
     * @throws Exception
     */
    public WxPayMpOrderResult pay(String outTradeNo, Long payConfigId, String amount, String openid) throws Exception {
        WxPayUnifiedOrderRequest orderRequest = new WxPayUnifiedOrderRequest();
        //商品描述
        orderRequest.setBody("订单预支付"); //String Body
        //订单号
        orderRequest.setOutTradeNo(outTradeNo);
        //金额
        orderRequest.setTotalFee(BaseWxPayRequest.yuanToFen(amount));//元转成分
        //openid
        orderRequest.setOpenid(openid);
        //IP地址
        InetAddress localHost = InetAddress.getLocalHost();
        orderRequest.setSpbillCreateIp(localHost.getHostAddress());
        //设置支付回调地址
        orderRequest.setNotifyUrl(myPayConfig.getNotifyUrl());
        orderRequest.setTradeType(myPayConfig.getTradeType());
        //获取当前时间
        LocalDateTime now = LocalDateTime.now();
        //当前时间加3分钟
        Date currentDate = new Date();
        currentDate.setTime(currentDate.getTime() + 180*1000);
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMddHHmmss");
        String formattedDate = dateFormat.format(currentDate);
        //订单失效时间
        orderRequest.setTimeExpire(formattedDate);
        WxPayMpOrderResult wxPayMpOrderResult = null;
        try {
            //调用微信支付接口
            wxPayMpOrderResult = wxPayService.createOrder(orderRequest);



        }catch (WxPayException wxPayException){
            //todo 微信支付接口支付异常
            System.out.println("微信支付接口支付异常日志！！");
            System.out.println(wxPayException);
        }
        System.out.println("订单支付返回参数----------------------\n"
                +wxPayMpOrderResult);
        return wxPayMpOrderResult;
    }

    /**
     * 退款接口
     * @param outTradeNo   订单号
     * @param outRefundNo  退款单号
     * @param totalFee     总金额
     * @param refundFee    退款金额
     * @return
     * @throws WxPayException
     */
    public WxPayRefundResult refund(String outTradeNo, String transactionId, String outRefundNo, Integer totalFee, Integer refundFee) throws WxPayException {
        WxPayRefundRequest request = new WxPayRefundRequest();
        request.setOutTradeNo(outTradeNo);
        request.setTransactionId(transactionId);
        request.setOutRefundNo(outRefundNo); //退款单号
        request.setTotalFee(totalFee);
        request.setRefundFee(refundFee);
        request.setOpUserId(myPayConfig.getMchId());
        request.setNotifyUrl(myPayConfig.getNotifyUrl());
        return wxPayService.refundV2(request);
    }
}
