package com.ruoyi.system.payment.service.impl;

import java.util.List;

import com.ruoyi.system.payment.domain.OrderRefundLog;
import com.ruoyi.system.payment.mapper.OrderRefundLogMapper;
import com.ruoyi.system.payment.service.IOrderRefundLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 微信退款回调Service业务层处理
 * 
 * @author 魏建波
 * @date 2024-07-03
 */
@Service
public class OrderRefundLogServiceImpl implements IOrderRefundLogService
{
    @Autowired
    private OrderRefundLogMapper orderRefundLogMapper;

    /**
     * 查询微信退款回调
     * 
     * @param refundLogId 微信退款回调主键
     * @return 微信退款回调
     */
    @Override
    public OrderRefundLog selectOrderRefundLogByRefundLogId(Long refundLogId)
    {
        return orderRefundLogMapper.selectOrderRefundLogByRefundLogId(refundLogId);
    }

    /**
     * 查询微信退款回调列表
     * 
     * @param orderRefundLog 微信退款回调
     * @return 微信退款回调
     */
    @Override
    public List<OrderRefundLog> selectOrderRefundLogList(OrderRefundLog orderRefundLog)
    {
        return orderRefundLogMapper.selectOrderRefundLogList(orderRefundLog);
    }

    /**
     * 新增微信退款回调
     * 
     * @param orderRefundLog 微信退款回调
     * @return 结果
     */
    @Override
    public int insertOrderRefundLog(OrderRefundLog orderRefundLog)
    {
        return orderRefundLogMapper.insertOrderRefundLog(orderRefundLog);
    }

    /**
     * 修改微信退款回调
     * 
     * @param orderRefundLog 微信退款回调
     * @return 结果
     */
    @Override
    public int updateOrderRefundLog(OrderRefundLog orderRefundLog)
    {
        return orderRefundLogMapper.updateOrderRefundLog(orderRefundLog);
    }

    /**
     * 批量删除微信退款回调
     * 
     * @param refundLogIds 需要删除的微信退款回调主键
     * @return 结果
     */
    @Override
    public int deleteOrderRefundLogByRefundLogIds(Long[] refundLogIds)
    {
        return orderRefundLogMapper.deleteOrderRefundLogByRefundLogIds(refundLogIds);
    }

    /**
     * 删除微信退款回调信息
     * 
     * @param refundLogId 微信退款回调主键
     * @return 结果
     */
    @Override
    public int deleteOrderRefundLogByRefundLogId(Long refundLogId)
    {
        return orderRefundLogMapper.deleteOrderRefundLogByRefundLogId(refundLogId);
    }
}
