package com.ruoyi.system.payment.service.impl;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.system.payment.domain.PayConfig;
import com.ruoyi.system.payment.mapper.PayConfigMapper;
import com.ruoyi.system.payment.service.IPayConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 支付配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-06-04
 */
@Service
public class PayConfigServiceImpl implements IPayConfigService
{
    @Autowired
    private PayConfigMapper payConfigMapper;

    /**
     * 查询支付配置
     * 
     * @param payConfigId 支付配置主键
     * @return 支付配置
     */
    @Override
    public PayConfig selectPayConfigByPayConfigId(Long payConfigId)
    {
        return payConfigMapper.selectPayConfigByPayConfigId(payConfigId);
    }

    /**
     * 查询支付配置列表
     * 
     * @param payConfig 支付配置
     * @return 支付配置
     */
    @Override
    public List<PayConfig> selectPayConfigList(PayConfig payConfig)
    {
        return payConfigMapper.selectPayConfigList(payConfig);
    }

    /**
     * 新增支付配置
     * 
     * @param PayConfig 支付配置
     * @return 结果
     */
    @Override
    public int insertPayConfig(PayConfig PayConfig)
    {
        PayConfig.setCreateTime(DateUtils.getNowDate());
        return payConfigMapper.insertPayConfig(PayConfig);
    }

    /**
     * 修改支付配置
     * 
     * @param PayConfig 支付配置
     * @return 结果
     */
    @Override
    public int updatePayConfig(PayConfig PayConfig)
    {
        PayConfig.setUpdateTime(DateUtils.getNowDate());
        return payConfigMapper.updatePayConfig(PayConfig);
    }

    /**
     * 批量删除支付配置
     * 
     * @param payConfigIds 需要删除的支付配置主键
     * @return 结果
     */
    @Override
    public int deletePayConfigByPayConfigIds(Long[] payConfigIds)
    {
        return payConfigMapper.deletePayConfigByPayConfigIds(payConfigIds);
    }

    /**
     * 删除支付配置信息
     * 
     * @param payConfigId 支付配置主键
     * @return 结果
     */
    @Override
    public int deletePayConfigByPayConfigId(Long payConfigId)
    {
        return payConfigMapper.deletePayConfigByPayConfigId(payConfigId);
    }
}
