package com.ruoyi.system.payment.service.impl;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.github.binarywang.wxpay.bean.notify.WxPayNotifyResponse;
import com.github.binarywang.wxpay.bean.notify.WxPayRefundNotifyResult;
import com.github.binarywang.wxpay.bean.order.WxPayMpOrderResult;
import com.github.binarywang.wxpay.bean.result.WxPayRefundResult;
import com.github.binarywang.wxpay.exception.WxPayException;
import com.github.binarywang.wxpay.service.WxPayService;
import com.ruoyi.common.core.utils.DateUtils;
import com.ruoyi.common.core.utils.StringUtils;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.system.app.base.domain.AppRechargeVO;
import com.ruoyi.system.app.base.service.AppBaseService;
import com.ruoyi.system.application.domain.TUOrder;
import com.ruoyi.system.application.service.ITUOrderService;
import com.ruoyi.system.payment.component.WeChatPayComponent;
import com.ruoyi.system.payment.domain.OrderRefundLog;
import com.ruoyi.system.payment.domain.PayLog;
import com.ruoyi.system.payment.domain.OrderPayRequest;
import com.ruoyi.system.payment.domain.RefundOrderRequest;
import com.ruoyi.system.payment.mapper.OrderRefundLogMapper;
import com.ruoyi.system.payment.service.IAccompanyPayLogService;
import com.ruoyi.system.payment.service.IPaymentService;
import com.ruoyi.system.payment.utils.ConverterUtil;
import com.ruoyi.system.payment.utils.SnowflakeIdUtils;
import com.ruoyi.system.wxpay.service.PayUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;

import javax.annotation.Resource;

/**
 * Created with IntelliJ IDEA.
 *
 * @author 魏建波
 * Date:  2024/6/13
 * Time:  10:50
 * @description
 */
@Service
public class PaymentServiceImpl implements IPaymentService {
    @Autowired
    WeChatPayComponent weChatPayComponent;
    @Autowired
    IAccompanyPayLogService payLogService;
    @Resource
    AppBaseService appBaseService;

    @Autowired
    private WxPayService wxService;

    @Override
    @Transactional
    public AjaxResult orderPay(OrderPayRequest orderPayRequest) throws Exception {
        // 生成一个雪花订单号
        SnowflakeIdUtils idWorker = new SnowflakeIdUtils(1, 2);
        // 订单编号
        String orderNo = String.valueOf(idWorker.nextId());
        // 支付编号
        String outTradeNo = String.valueOf(idWorker.nextId());
        // 生成预支付订单
        WxPayMpOrderResult wxPayMpOrderResult = weChatPayComponent.pay(outTradeNo, orderPayRequest.getPayConfigId(), orderPayRequest.getAccount(),
                orderPayRequest.getOpenid());
        // 日志存储到数据库
        String appId = wxPayMpOrderResult.getAppId();
        String timeStamp = wxPayMpOrderResult.getTimeStamp();
        String packageValue = wxPayMpOrderResult.getPackageValue();
        String signType = wxPayMpOrderResult.getSignType();
        String paySign = wxPayMpOrderResult.getPaySign();
        String nonceStr = wxPayMpOrderResult.getNonceStr();
        PayLog payLog = new PayLog();
        payLog.setAppId(appId);
        payLog.setTimeStamp(Long.parseLong(timeStamp));
        payLog.setPackageValue(packageValue);
        payLog.setSignType(signType);
        payLog.setPaySign(paySign);
        payLog.setNonceStr(nonceStr);
        payLog.setOpenid(orderPayRequest.getOpenid());
        payLog.setOutTradeNo(outTradeNo);
        payLog.setBody("订单支付");
        payLog.setUserId(orderPayRequest.getUserId());
        // 设置订单编号
        payLog.setOrderId(orderPayRequest.getOrderId());
        payLog.setCreateTime(DateUtils.getNowDate());
        //todo 设置用户id 用户类型
        payLog.setUserId(orderPayRequest.getUserId());
        payLog.setUserType(orderPayRequest.getUserType());
        // 设置用户类型
        payLogService.insertAccompanyPayLog(payLog);
        return AjaxResult.success(wxPayMpOrderResult);
    }

    @Override
    @Transactional
    public AjaxResult orderTest(OrderPayRequest orderPayRequest) throws Exception {
        // 生成一个雪花订单号
        SnowflakeIdUtils idWorker = new SnowflakeIdUtils(1, 2);
        // 订单编号
        String orderNo = String.valueOf(idWorker.nextId());
        // 支付编号
        String outTradeNo = String.valueOf(idWorker.nextId());
        // 生成预支付订单

        WxPayMpOrderResult wxPayMpOrderResult = weChatPayComponent.pay(outTradeNo, orderPayRequest.getPayConfigId(), orderPayRequest.getAccount(),
                orderPayRequest.getOpenid());
        return AjaxResult.success(wxPayMpOrderResult);
    }

    @Override
    public String callbackNotifyOrder(String xmlData) throws WxPayException {

        System.out.println("&&&&&&&&&&&&&&&&&&&&&&&&&&&&");
        System.out.println(xmlData);
        System.out.println("&&&&&&&&&&&&&&&&&&&&&&&&&&&&");
        Map map = null;
        try {
            map = PayUtil.doXMLParse(xmlData);
        } catch (Exception e) {
            e.printStackTrace();
        }

//        WxPayOrderNotifyResult wxPayOrderNotifyResult = wxService.parseOrderNotifyResult(xmlData);
//        String returnCode = wxPayOrderNotifyResult.getReturnCode();
//        String outTradeNo = wxPayOrderNotifyResult.getOutTradeNo();
        String returnCode = map.get("return_code").toString();
        String outTradeNo = map.get("out_trade_no").toString();

        // 查询支付日志  是否存在
        PayLog requestPayLog = new PayLog();
        requestPayLog.setOutTradeNo(outTradeNo);
        PayLog wechatPayLog = null;
        List<PayLog> wechatPayLogList = payLogService.selectAccompanyPayLogList(requestPayLog);
        if (returnCode != null && "SUCCESS".equals(returnCode)) {
            wechatPayLog = wechatPayLogList.get(0);
            if (wechatPayLogList != null && wechatPayLogList.size() > 0) {
                // 验证是否回调完成
                if (StringUtils.isNotEmpty(wechatPayLog.getTransactionId())) {
                    return WxPayNotifyResponse.fail("存在回调信息！");
                }
                //微信支付订单id
//                String transactionId = wxPayOrderNotifyResult.getTransactionId();
                String transactionId = map.get("transaction_id").toString();
                System.out.println("transactionId" + transactionId);
                //todo 修改微信支付日志回调状态
//                String timeEnd = wxPayOrderNotifyResult.getTimeEnd();
//                Integer totalFee = wxPayOrderNotifyResult.getTotalFee();
//                String tradeType = wxPayOrderNotifyResult.getTradeType();
                String timeEnd = map.get("time_end").toString();
                Integer totalFee = Integer.parseInt( map.get("total_fee").toString());
                String tradeType =map.get("trade_type").toString();
                try {
                    SimpleDateFormat formatter = new SimpleDateFormat("yyyyMMddHHmmss");
                    Date date = formatter.parse(timeEnd);
                    wechatPayLog.setTimeEnd(date);
                } catch (Exception e) {
                    e.printStackTrace();
                }
                wechatPayLog.setTotalFee(new BigDecimal(totalFee));
                wechatPayLog.setTradeType(tradeType);
                wechatPayLog.setTransactionId(transactionId);
                wechatPayLog.setCallResultCode(returnCode);
                int i = payLogService.updateAccompanyPayLog(wechatPayLog);
            }
            //  todo 改变订单状态
            String orderId = wechatPayLog.getOrderId();
            // 付款时间 格式化支付时间
            DateTime time = DateUtil.parse(map.get("time_end").toString());
            Date date = new Date(time.getTime());
            // todo 回调是否加 看业务
            Long userId = wechatPayLog.getUserId();
            String userType = wechatPayLog.getUserType();
            Integer money =Integer.parseInt(wechatPayLog.getTotalFee().toString())  ;
            // todo 调用改变订单状态方法
            //----------------------------------------------支付back--recharge  sunyishi-----------------------------------------------
            AppRechargeVO rechargeVO = new AppRechargeVO();
            rechargeVO.setUserId(userId);
            rechargeVO.setMoney(money);
            rechargeVO.setOpenid(wechatPayLog.getOpenid());
            rechargeVO.setPaymentId(wechatPayLog.getPayLogId());
            appBaseService.rechargeBack(rechargeVO);



            return WxPayNotifyResponse.success("处理成功!");
        } else if (returnCode != null && "FAIL".equals(returnCode)) {
            //todo 回调失败
            wechatPayLog.setCallResultCode(returnCode);
            wechatPayLog.setErrMsg(returnCode);
            int i = payLogService.updateAccompanyPayLog(wechatPayLog);
            return WxPayNotifyResponse.fail("回调失败！");
        } else {
            return WxPayNotifyResponse.fail("非法参数！");
        }
    }

    @Autowired
    private ITUOrderService tUOrderService;
    @Resource
    private OrderRefundLogMapper orderRefundLogMapper;

    @Override
    @Transactional
    public String refundOrder(RefundOrderRequest refundOrderRequest) throws Exception {
        // 记录一下退款日志
        TUOrder order = tUOrderService.selectTUOrderById(refundOrderRequest.getOrderId());
        //生成out_refund_no商户系统内部的退款单号唯一
        SnowflakeIdUtils idUtils =new SnowflakeIdUtils(1,2);
        String outRefundNo = String.valueOf(idUtils.nextId());
        // 价格单位为分
        BigDecimal totalFee = refundOrderRequest.getTotalFee().multiply(new BigDecimal(100));
        BigDecimal refundFee = refundOrderRequest.getRefundFee().multiply(new BigDecimal(100));
        // 开始调用接口支付
        WxPayRefundResult refundResult = weChatPayComponent.refund(null,refundOrderRequest.getTransactionId(),
                outRefundNo, totalFee.intValue(), refundFee.intValue());
        OrderRefundLog refundLog = ConverterUtil.convertToClass(refundResult, OrderRefundLog.class);
        System.out.println("退货结果返回：");
        System.out.println(refundLog);
        if("SUCCESS".equals(refundResult.getResultCode())){
            // 2-更新订单表
            //todo 退款中字典值是什么  就填写什么
            order.setOrderStatus("退款中"); // 设置状态为退款中
            tUOrderService.updateTUOrder(order);
            // 3-添加记录
            refundLog.setOrderId(order.getId()); //存储订单id 作为关联字段
            refundLog.setIsNotify(0); //是否回调 0 默认没有回调  在回调后
            orderRefundLogMapper.insertOrderRefundLog(refundLog);
        }else{
            // throw new ServiceException("支付异常，请联系支付公司");
            refundLog.setOrderId(order.getId()); //存储订单id 作为关联字段
            orderRefundLogMapper.insertOrderRefundLog(refundLog);
            return "success";
        }
        return null;
    }

    @Override
    @Transactional
    public String callbackRefundNotifyOrder(String xmlData) {
        try {
            final WxPayRefundNotifyResult result = wxService.parseRefundNotifyResult(xmlData);
            System.out.println("-----------------------------------------------------------------------------------------");
            System.out.println("-------------------------回调参数-------------------------------------------------------");
            WxPayRefundNotifyResult.ReqInfo reqInfo = result.getReqInfo();
            String outTradeNo = reqInfo.getOutTradeNo();
            System.out.println("outTradeNo!!" + outTradeNo);
            String outRefundNo = reqInfo.getOutRefundNo();
            System.out.println("outRefundNo!!" + outRefundNo);
            String refundId = reqInfo.getRefundId();
            System.out.println("refundId!!" + refundId);
            Integer refundFee = reqInfo.getRefundFee();
            System.out.println("refundFee!!" + refundFee);
            String refundAccount = reqInfo.getRefundAccount();
            System.out.println("refundAccount!!" + refundAccount);
            String refundStatus = reqInfo.getRefundStatus();
            System.out.println("refundStatus!!" + refundStatus);
            String successTime = reqInfo.getSuccessTime();
            System.out.println("successTime!!" + successTime);
            String refundRecvAccout = reqInfo.getRefundRecvAccout();
            System.out.println("refundRecvAccout!!" + refundRecvAccout);
            //todo 对退款回调进行保存标记 根据outRefundNo进行查找
            OrderRefundLog refundLog = new OrderRefundLog();
            refundLog.setOutRefundNo(outRefundNo);
            List<OrderRefundLog> list =orderRefundLogMapper.selectOrderRefundLogList(refundLog);
            if(list.size()>0){
                // 存在信息
                refundLog.setIsNotify(1); // 回调成功 1
                refundLog.setNotifyTime(DateUtils.getNowDate());
                refundLog.setNotifyRemark(refundRecvAccout);
                int i = orderRefundLogMapper.updateOrderRefundLog(refundLog);
                // todo 处理订单
                TUOrder order = tUOrderService.selectTUOrderById(list.get(0).getOrderId());
                //todo 退款中字典值是什么  就填写什么
                order.setOrderStatus("退款完成"); // 设置状态为退款中
                tUOrderService.updateTUOrder(order);
                return WxPayNotifyResponse.success("处理成功!");
            }
            return WxPayNotifyResponse.success("找不到对应的日志信息!");
        } catch (WxPayException e) {
            System.out.println("微信退款回调结果解析异常,异常原因{}" + e.getMessage());
            return WxPayNotifyResponse.fail(e.getMessage());
        }

    }
}